@@ -1,9 +1,9 @@
-/*  
-    Geodesy and Mapping C++ Library (GNU GaMa / GaMaLib)
+/*
+    GNU Gama -- adjustment of geodetic networks
     Copyright (C) 1999  Ales Cepek <cepek@gnu.org>
 
     This file is part of the GNU Gama C++ Library.
-    
+
     This library is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation; either version 3 of the License, or
@@ -19,10 +19,6 @@
     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
-/*
- *  $Id: rand.cpp,v 1.2 2007/06/26 15:04:09 cepek Exp $
- */
-
 #include <gnu_gama/rand.h>
 
 #ifndef _MSC_VER
@@ -41,7 +37,7 @@ void IRAND55::IN55(long seed)
    ia[55] = seed;
    long j = seed;
    long k = 1;
-   
+
    for (long ii, i=1; i<=54; i++)
       {
          ii = 21*i % 55;
