@@ -1,9 +1,9 @@
-/*  
-    Geodesy and Mapping C++ Library (GNU GaMa / GaMaLib)
+/*
+    GNU Gama -- adjustment of geodetic networks
     Copyright (C) 2000  Petr Doubrava <petr@gepro.cz>
 
-    This file is part of the GNU GaMa / GaMaLib C++ Library.
-    
+    This file is part of the GNU Gama C++ library.
+
     This library is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation; either version 3 of the License, or
@@ -19,14 +19,10 @@
     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
-/*
- *  $Id: encoding.h,v 1.2 2007/06/26 15:04:11 cepek Exp $
- */
-
 #include <gnu_gama/xml_expat.h>
 
-#ifndef GaMaLib_GKF__XML__encoding__h_
-#define GaMaLib_GKF__XML__encoding__h_
+#ifndef gama_local_GKF__XML__encoding__h_
+#define gama_local_GKF__XML__encoding__h_
 
 
 #ifdef __cplusplus
@@ -46,7 +42,7 @@ int   UnknownEncodingHandler(void *userData, const char *name,
                            XML_Encoding *info);
 
 #ifdef __cplusplus
-}  // namespace GNU_gama                
+}  // namespace GNU_gama
 #endif
 
 
