@@ -1,9 +1,9 @@
-/*  
-    Geodesy and Mapping C++ Library (GNU GaMa / GaMaLib)
+/*
+    GNU Gama -- adjustment of geodetic networks
     Copyright (C) 2003  Ales Cepek <cepek@gnu.org>
 
     This file is part of the GNU Gama C++ Library.
-    
+
     This library is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation; either version 3 of the License, or
@@ -19,10 +19,6 @@
     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
-/*
- *  $Id: xml_expat.h,v 1.2 2007/06/26 15:04:09 cepek Exp $
- */
-
 #ifndef GNU_gama_xml_expat_h___GNU_Gama_interface_for_Expat_XML_parser
 #define GNU_gama_xml_expat_h___GNU_Gama_interface_for_Expat_XML_parser
 
