@@ -1,6 +1,6 @@
 /*
-    C++ Matrix/Vector templates (GNU Gama / matvec 1.0.01)
-    Copyright (C) 1999, 2007  Ales Cepek <cepek@gnu.org>
+    C++ Matrix/Vector templates (GNU Gama / matvec)
+    Copyright (C) 1999, 2007, 2012  Ales Cepek <cepek@gnu.org>
 
     This file is part of the GNU Gama C++ Matrix/Vector template library.
 
@@ -23,7 +23,6 @@
 #define GNU_gama_gMatVec_TransVec__h_
 
 #include <iostream>
-#include <cstdarg>
 #include <cmath>
 #include <matvec/vec.h>
 
@@ -43,13 +42,13 @@ public:
   TransVec(const VecBase<Float, Exc>& v) : VecBase<Float, Exc>(v) {}
 
   TransVec operator*(Float f) const {
-      TransVec t(this->dim()); mul(f, t); return t;
+      TransVec t(this->dim()); this->mul(f, t); return t;
     }
   TransVec operator+(const TransVec &x) const {
-    TransVec t(this->dim()); add(x, t); return t;
+    TransVec t(this->dim()); this->add(x, t); return t;
   }
   TransVec operator-(const TransVec &x) const {
-    TransVec t(this->dim()); sub(x, t); return t;
+    TransVec t(this->dim()); this->sub(x, t); return t;
   }
 
 };
